@@ -5,8 +5,10 @@ from subprocess import (
     run,
 )
 
+from pybrary.ascii import rm_ansi_codes
 
-def shell(script, shell):
+
+def shell(script, shell, color=False):
     try:
         proc = run(
             script,
@@ -24,6 +26,11 @@ def shell(script, shell):
         ret = proc.returncode
         out = proc.stdout.decode('utf-8').strip()
         err = proc.stderr.decode('utf-8').strip()
+
+    if not color:
+        out = rm_ansi_codes(out)
+        err = rm_ansi_codes(err)
+
     return ret, out, err
 
 
